/*
 * Copyright 2013  Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* Pure virtual class */
class CLiveBox
{
public:
	CLiveBox(void) {};
	virtual ~CLiveBox(void) {}

	virtual int Create(const char *filename, const char *content, const char *cluster, const char *category) = 0;
	virtual int Destroy(void) = 0;

	virtual int NeedToUpdate(void) = 0;
	virtual int NeedToDestroy(void) = 0;
	virtual int UpdateContent(void) = 0;

	/*!
	 * \param[in] event "clicked" only
	 */
	virtual int Clicked(const char *event, double timestamp, double x, double  y) = 0;
	virtual int ContentEvent(const char *emission, const char *source, struct event_info *info) = 0;

	/*!
	 * if "source" == "filename", emission could be "pd,show", "pd,hide", "lb,show", "lb,hide".
	 */
	virtual int Resize(int type) = 0;
	virtual int ChangeGroup(const char *cluster, const char *category) = 0;
	virtual int GetInfo(int *w, int *h, double *priority, char **content, char **title) = 0;
	virtual char *PinUp(int on_pin) = 0;
	virtual const char *Filename(void) = 0;
	virtual int IsPinnedUp(void) = 0;
	virtual int SystemEvent(int event) = 0;
};

/* End of a file */
